@@ -1,14 +1,13 @@
 #include <config.h>
 #include <string.h>
 #include <stdlib.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <libgnome/gnome-config.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-client.h>
 #include <libgnomeui/gnome-ui-init.h>
 #include <libgnomeui/gnome-authentication-manager.h>
+#include <libgnomeui/gnome-app-helper.h>
 #include <gconf/gconf-client.h>
-#include "util.h"
 #include "eog-window.h"
 #include "eog-thumbnail.h"
 #include "session.h"
@@ -35,6 +34,7 @@ typedef struct {
 #ifdef G_OS_WIN32
 
 #include <windows.h>
+#include "util.h"
 
 static const char *
 get_installation_subdir (const char *configure_time_path)
@@ -104,19 +104,6 @@ eog_get_localedir (void)
 #endif	/* G_OS_WIN32 */
 
 
-static void 
-free_uri_list (GList *list)
-{
-	GList *it;
-	
-	for (it = list; it != NULL; it = it->next) {
-		gnome_vfs_uri_unref ((GnomeVFSURI*)it->data);
-	}
-
-	if (list != NULL) 
-		g_list_free (list);
-}
-
 static void 
 free_string_list (GList *list)
 {
@@ -135,7 +122,7 @@ load_context_free (LoadContext *ctx)
 {
 	if (ctx == NULL) return;
 
-	free_uri_list (ctx->uri_list);
+	gnome_vfs_uri_list_free (ctx->uri_list);
 	if (ctx->img_list != NULL)
 			g_object_unref (ctx->img_list);
 	ctx->img_list = NULL;
@@ -516,7 +503,7 @@ open_uri_list_cb (EogWindow *window, GSList *uri_list, gpointer data)
 	/* open every directory in an own window */
 	if (dir_list) {
 		quit_program = FALSE;
-		load_uris_in_single_model (window, dir_list);		
+		load_uris_in_single_model (window, dir_list);
 		g_list_free (dir_list);
 	}
 
@@ -554,6 +541,9 @@ handle_cmdline_args (gpointer data)
 	startup_file_list = string_array_to_list ((const gchar **) startup_files);
 	
 	open_uri_list_cb (NULL, startup_file_list, NULL);
+
+	g_slist_foreach (startup_file_list, (GFunc) g_free, NULL);
+	g_slist_free (startup_file_list);
 	
 	return FALSE;
 }
@@ -620,7 +610,7 @@ main (int argc, char **argv)
 #endif
 	eog_thumbnail_init ();
 
-	gtk_window_set_default_icon_name ("image-viewer");
+	gtk_window_set_default_icon_name ("eog");
 
 	client = gnome_master_client ();
 
@@ -636,6 +626,8 @@ main (int argc, char **argv)
 
 	gtk_main ();
 
+	gnome_accelerators_sync();
+	
 	g_object_unref (program);
 
 	return 0;
